@@ -1,5 +1,5 @@
 /*
-    Copyright 2012  Dan Vratil <dan@progdan.cz>
+    Copyright (C) 2012 - 2018  Daniel Vrátil <dvratil@kde.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
@@ -161,7 +161,9 @@ class KGAPICORE_EXPORT AuthWidget : public QWidget
      */
     void progress(KGAPI2::AuthWidget::Progress progress);
 
-  private:
+  protected:
+    AuthWidget(AuthWidgetPrivate *dptr, QWidget *parent = nullptr);
+
     AuthWidgetPrivate * const d;
     friend class AuthWidgetPrivate;
     friend class AuthJob;
