@@ -1,5 +1,5 @@
 /*
-    Copyright 2012  Dan Vratil <dan@progdan.cz>
+    Copyright (C) 2012 - 2018  Daniel Vrátil <dvratil@kde.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
@@ -25,26 +25,33 @@
 
 #include "ui/authwidget.h"
 #include "types.h"
+#include "kgapicore_export.h"
 
 #include <QLineEdit>
 #include <QToolButton>
 #include <QProgressBar>
-#include <QWebEngineView>
-#include <QTcpServer>
+#include <QAbstractSocket>
 
 class QVBoxLayout;
 class QLabel;
+class QWebEngineView;
+class QTcpServer;
+class QTcpSocket;
 
 namespace KGAPI2 {
 
 class Job;
 
-class Q_DECL_HIDDEN AuthWidgetPrivate: public QObject {
+// Exported for tests, otherwise internal
+class KGAPICORE_EXPORT AuthWidgetPrivate: public QObject {
 
     Q_OBJECT
 
   public:
     explicit AuthWidgetPrivate(AuthWidget *parent);
+    virtual void setupUi();
+    virtual void setUrl(const QUrl &url);
+    virtual void setVisible(bool visible);
 
     ~AuthWidgetPrivate() override;
 
@@ -57,15 +64,15 @@ class Q_DECL_HIDDEN AuthWidgetPrivate: public QObject {
     QString apiKey;
     QString secretKey;
 
-    QToolButton *sslIndicator;
-    QLineEdit *urlEdit;
-    QProgressBar *progressbar;
-    QVBoxLayout *vbox;
-    QWebEngineView *webview;
-    QLabel *label;
+    QToolButton *sslIndicator = nullptr;
+    QLineEdit *urlEdit = nullptr;
+    QProgressBar *progressbar = nullptr;
+    QVBoxLayout *vbox = nullptr;
+    QWebEngineView *webview = nullptr;
+    QLabel *label = nullptr;
 
     QTcpServer *server = nullptr;
-    int serverPort = -1;
+    int serverPort = 0;
     QTcpSocket *connection = nullptr;
 
   private Q_SLOTS:
@@ -79,7 +86,6 @@ class Q_DECL_HIDDEN AuthWidgetPrivate: public QObject {
     void accountInfoReceived(KGAPI2::Job *job);
 
   private:
-    void setupUi();
     void setProgress(AuthWidget::Progress progress);
 
     bool isGoogleHost(const QUrl &url) const { return url.host() == QLatin1String("accounts.google.com"); }
